@@ -107,11 +107,9 @@ automatically with the nose unit testing framework (nosetests).
 (c) 2009 by Eric O. LEBIGOT (EOL) <eric.lebigot@normalesup.org>
 Please send feature requests, bug reports, or compliments to this address.
 
-This software is released under a dual license.  (1) The GNU General 
-Public License version 2 (http://creativecommons.org/licenses/GPL/2.0/).
-(2) It is also possible to use this software under another license (in 
-particular for commercial uses), which must then be obtained from the 
-original author.'''
+This software is released under a dual license.  (1) The GNU General \
+Public License version 2.  (2) Any other license, as long as it is \
+obtained from the original author.'''
 
 # The idea behind this module is to replace the result of mathematical
 # operations by a local approximation of the defining function.  For
